summaryrefslogtreecommitdiffstats
path: root/system/libraries/Session/drivers
diff options
context:
space:
mode:
authorMichael Long <mchobbylong@gmail.com>2019-09-03 19:13:50 +0200
committerMichael Long <mchobbylong@gmail.com>2019-09-03 19:13:50 +0200
commitb373b9b099a5df0b180128d83fb3bf3f44877280 (patch)
tree0b30c61f807699fb35304d52624603a1b2c7723b /system/libraries/Session/drivers
parenta9f13251df09ceb179ce6a9f6440a6869e779bba (diff)
Rename to _ping_success
Diffstat (limited to 'system/libraries/Session/drivers')
-rw-r--r--system/libraries/Session/drivers/Session_redis_driver.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/system/libraries/Session/drivers/Session_redis_driver.php b/system/libraries/Session/drivers/Session_redis_driver.php
index ea70e4946..cb6bf3645 100644
--- a/system/libraries/Session/drivers/Session_redis_driver.php
+++ b/system/libraries/Session/drivers/Session_redis_driver.php
@@ -97,11 +97,11 @@ class CI_Session_redis_driver extends CI_Session_driver implements SessionHandle
protected $_delete_name;
/**
* Response of ping() method in phpRedis
*
* @var mixed
*/
- protected $_ping_response;
+ protected $_ping_success;
// ------------------------------------------------------------------------
@@ -120,13 +120,13 @@ class CI_Session_redis_driver extends CI_Session_driver implements SessionHandle
{
$this->_setTimeout_name = 'expire';
$this->_delete_name = 'del';
- $this->_ping_response = TRUE;
+ $this->_ping_success = TRUE;
}
else
{
$this->_setTimeout_name = 'setTimeout';
$this->_delete_name = 'delete';
- $this->_ping_response = '+PONG';
+ $this->_ping_success = '+PONG';
}
if (empty($this->_config['save_path']))
@@ -313,7 +313,7 @@ class CI_Session_redis_driver extends CI_Session_driver implements SessionHandle
if (isset($this->_redis))
{
try {
- if ($this->_redis->ping() === $this->_ping_response)
+ if ($this->_redis->ping() === $this->_ping_success)
{
$this->_release_lock();
if ($this->_redis->close() === FALSE)
@@ -97,11 +97,11 @@ class CI_Session_redis_driver extends CI_Session_driver implements SessionHandle
protected $_delete_name;
/**
- * Response of ping() method in phpRedis
+ * Success return value of ping() method in phpRedis
*
* @var mixed